# Authors

AiiDA-VASP is now maintained by Espen Flage-Larsen, Sigma2, Norway.

## Development Team

- Espen Flage-Larsen, Sigma2, Norway (maintainer)
- Atsushi Togo, NIMS, Japan
- Bonan Zhu, University College London, United Kingdom
- Jonathan Chico, AB Sandvik Coromant, Department of Materials Design and Modeling, Sweden

## Acknowledgements

Special thanks go to the following individuals and organizations that helps or helped in the development.

- Sebastiaan Huber, Microsoft Quantum (bugfixes)
- Kohei Shinohara, Kyoto University (bugfixes)
- Michael Wolloch, VASP Software GmbH (discussions, bugfixes)
- Vladislav Nikolaev, Moscow Institute of Physics and Technology, Russia (bugfixes)
- Martin Callsen, Gent University (for extensive work on the parser)
- Rico Häuselmann, THEOS, EPFL (big thanks for the initial design and implementation of the plugin compatible with AiiDA 0.x)
- Dominik Gresch, ITP, ETHZ
- Abel Carreras, Kyoto University for testing and finding many issues
- Georg Wolfgang Winkler, ITP, ETHZ for testing in the early stages
- Giovanni Pizzi, THEOS, EPFL for writing \[AiiDA\](<https://github.com/aiidateam/aiida_core>) in the first place
- Daniel Marchand for discussions, bug reports and bugfixing
- \[aiidateam\](<https://github.com/aiidateam>) for supporting plugin developpers
